==> qtjambi-sensors-6.5.3-sources.jar: io/qt/sensors/QGyroscope.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qgyroscope.html">QGyroscope</a></code></p>
 */
public class QGyroscope extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QGyroscope.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qgyroscope.html#QGyroscope">QGyroscope::<wbr>QGyroscope(QObject*)</a></code></p>
     */
    public QGyroscope(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QGyroscope instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qsensor.html#reading-prop">QSensor::<wbr>reading()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.sensors.@Nullable QGyroscopeReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.sensors.QGyroscopeReading reading_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QGyroscope(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QGyroscope(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QGyroscope instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QGyroscope(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QGyroscope() {
        this((io.qt.core.QObject)null);
    }
}

==> qtjambi-sensors-6.6.2-sources.jar: io/qt/sensors/QGyroscope.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qgyroscope.html">QGyroscope</a></code></p>
 */
public class QGyroscope extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QGyroscope.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qgyroscope.html#QGyroscope">QGyroscope::<wbr/>QGyroscope(QObject*)</a></code></p>
     */
    public QGyroscope(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QGyroscope instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qsensor.html#reading-prop">QSensor::<wbr/>reading()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.sensors.@Nullable QGyroscopeReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.sensors.QGyroscopeReading reading_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QGyroscope(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QGyroscope(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QGyroscope instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QGyroscope(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QGyroscope() {
        this((io.qt.core.QObject)null);
    }
}
